require 'spec_helper'
require 'file_classify'

BINARY_FILE = 'spec/resources/binary.jpg'
ASCII_FILE = 'spec/resources/ascii.txt'

describe FileClassify do
  let :binary_contents_subject do
    FileClassify.new(contents: File.read(BINARY_FILE))
  end

  let :binary_ascii_8bit_contents_subject do
    FileClassify.new(contents: File.read(BINARY_FILE).force_encoding('ascii-8bit'))
  end

  let :binary_path_subject do
    FileClassify.new(path: BINARY_FILE)
  end

  let :ascii_contents_subject do
    FileClassify.new(contents: File.read(ASCII_FILE))
  end

  let :ascii_path_subject do
    FileClassify.new(path: ASCII_FILE)
  end

  context '#initialize' do
    it 'path' do
      fc = FileClassify.new(path: BINARY_FILE)
      fc.path.should == BINARY_FILE
    end

    it 'contents' do
      fc = FileClassify.new(contents: File.read(BINARY_FILE))
      fc.contents.should == File.read(BINARY_FILE)
    end

    it 'no args' do
      expect { FileClassify.new }.to raise_error(ArgumentError)
    end
  end

  context '#classify' do
    it 'binary' do
      binary_contents_subject.classify.should == 'binary'
      binary_path_subject.classify.should == 'binary'
    end

    it 'ascii' do
      ascii_contents_subject.classify.should == 'ascii'
      ascii_path_subject.classify.should == 'ascii'
    end
  end

  context '#binary?' do
    it 'binary' do
      binary_contents_subject.binary?.should be_true
      binary_path_subject.binary?.should be_true
    end

    it 'ascii' do
      ascii_contents_subject.binary?.should be_false
      ascii_path_subject.binary?.should be_false
    end

    it 'handles ascii-8bit encoded content strings' do
      binary_ascii_8bit_contents_subject.binary?.should be_true
    end
  end

  context '#ascii?' do
    it 'ascii' do
      ascii_contents_subject.ascii?.should be_true
      ascii_path_subject.ascii?.should be_true
    end

    it 'binary' do
      binary_contents_subject.ascii?.should be_false
      binary_path_subject.ascii?.should be_false
    end
  end
end
